@@ -16,11 +16,11 @@ expect "download:" {send "04b8af94-ecea-4377-bf8c-19592d3ac4f7\n"}
 expect "Enter correct IP address of this machine (Example: 123.123.123.123):" {send $::env(HOST_IP)\r"}
 expect EOF'
 
-Grafana_password=$(kubectl get secrets/grafana -n telemetry -o json | jq -r '.data."admin-password"' | base64 -d)
 HOST_IP=$(hostname -I | awk '{print $1}')
 echo -e "\e[1;32mData Visualization on Grafana\e[0m"
 echo -e "\e[1;36m1. Navigate to https://$HOST_IP:30300/dashboard on your browser to check the Wireless Network Ready ITM dashboard.\e[0m"
 echo -e "\e[1;36m\n2. Navigate to https://$HOST_IP:32000 on your browser to login to the Grafana dashboard.\e[0m"
 echo -e "\e[1;32m\nLogin with the below mentioned credentials"
 echo -e "\e[1;33mUsername : admin\e[0m"
-echo -e "\e[1;33mGrafana Password : $Grafana_password\e[0m"
+GRAFANA_PWD=$(kubectl get secrets/grafana -n telemetry -o json | jq -r '.data."admin-password"' | base64 -d)
+echo -e "\e[1;33mGrafana Password : $GRAFANA_PWD\e[0m"
